---
author: Wu Sun (<wu.sun@ucla.edu>)

title: Metadata Information for the San Joaquin Freshwater Marsh Leaf Flux Data

date: 2018-03-07
---


# General description
* Name of the dataset: San Joaquin Freshwater Marsh Leaf Flux Data (Version 2018.03.07)
* Investigators:
    - UCLA: Wu Sun, Ulli Seibt
    - The Open University (UK): Kadmiel Maseyk
    - LSCE (France): Céline Lett
* Publication: Sun, W., Maseyk, K., Lett, C. and Seibt, U. (2017). Stomatal control of leaf fluxes of carbonyl sulfide and CO~2~ in a *Typha* freshwater marsh. *Biogeosciences Discuss.*, https://doi.org/10.5194/bg-2017-431, in review.
* Site location: San Joaquin Marsh (UC Natural Reserve), Irvine, California (33.662333 N, 117.851139 W, altitude 3 m). More information is available at <http://www.ucnrs.org/reserves/san-joaquin-marsh-reserve.html>.
* Period of the record: 31 May 2013 through 6 July 2013
* Funding sources: European Research Council (ERC) Starting Grant #202835 and NSF CAREER Award #1455381 to U.S.


# Terms of use
This dataset is made available under the Creative Commons CC0 1.0 Universal (CC0 1.0) Public Domain Dedication license: https://creativecommons.org/publicdomain/zero/1.0/, per policy of DataONE Dash (https://oneshare.cdlib.org/), an online self-service tool of UC3 Merritt data repository. For a plain language summary of the CC0 1.0 license, please see https://creativecommons.org/publicdomain/zero/1.0/. Please cite the original publication when using this dataset.


# Data file description
All data files are in CSV format with UTF-8 encoding and are readable through Microsoft Excel or mainstream scientific programming languages like Python and R. Description of data files and variables are as follows.

## Leaf flux and meteorological data
File name: `sjm2013_leaf_fluxes.csv`

Variable list

- `datetime_utc`: Date and time in UTC following the ISO 8601 standard (`yyyy-mm-dd HH:MM:SS`).
- `doy_utc`: Days since 1 Jan 2013 00:00 (UTC).
- `doy_local`: Days since 1 Jan 2013 00:00 in local summer time (Pacific Daylight Time, or UTC–7).
- `cos_atm`, `sd_cos_atm`: Atmospheric concentration of COS at 5 m height and its standard deviation in parts per trillion (pmol mol^–1^).
- `co2_atm`, `sd_co2_atm`: Atmospheric concentration of CO~2~ at 5 m height and its standard deviation in parts per million (µmol mol^–1^).
- `h2o_atm`, `sd_h2o_atm`: Atmospheric concentration of H~2~O at 5 m height and its standard deviation in parts per thousand (mmol mol^–1^).
- `cos_can`, `sd_cos_can`: Canopy concentration of COS at 2 m height and its standard deviation in parts per trillion (pmol mol^–1^).
- `co2_can`, `sd_co2_can`: Canopy concentration of CO~2~ at 2 m height and its standard deviation in parts per million (µmol mol^–1^).
- `h2o_can`, `sd_h2o_can`: Canopy concentration of H~2~O at 2 m height and its standard deviation in parts per thousand (mmol mol^–1^).
- `cos_lcc_bld`: COS concentration baseline drift (pmol mol^–1^) during leaf chamber measurements.
- `co2_lcc_bld`: CO~2~ concentration baseline drift (µmol mol^–1^) during leaf chamber measurements.
- `h2o_lcc_bld`: H~2~O concentration baseline drift (mmol mol^–1^) during leaf chamber measurements.
- `fcos_lc`, `sd_fcos_lc`: Leaf COS flux and its standard error (pmol m^–2^ s^–1^).
- `fco2_lc`, `sd_fco2_lc`: Leaf CO~2~ flux and its standard error (µmol m^–2^ s^–1^).
- `fh2o_lc`, `sd_fh2o_lc`: Leaf H~2~O flux and its standard error (mmol m^–2^ s^–1^).
- `T_atm`: Atmospheric temperature (°C) at 5 m height.
- `rh_atm`: Atmospheric relative humidity at 5 m height.
- `f_ch_lc`: Leaf chamber flow rate at ambient temperature (liter per minute).
- `T_ch_lc`: Air temperature (°C) inside the leaf chamber.
- `T_leaf`: Leaf temperature (°C) during the opening period before flux measurement.
- `PAR_EC`: Photosynthetically available radiation flux (µmol m^–2^ s^–1^) received at the eddy covariance tower (5 m).
- `PAR_ch`: Photosynthetically available radiation flux (µmol m^–2^ s^–1^) received near the leaf chamber (2 m).
- `Tch_b_lc`: Air temperature (°C) inside the leaf chamber during the opening period before flux measurement.
- `MFVD_atm`: Mole fraction water vapor deficit in the atmosphere (mmol H~2~O mol^–1^ air).
- `MFVD_lc`, `sd_MFVD_lc`: Mole fraction water vapor deficit in the leaf chamber, and its standard deviation (mmol H~2~O mol^–1^ air).
- `g_sw`: Stomatal conductance (mol m^–2^ s^–1^) estimated from leaf water flux (`fh2o_lc`) and vapor deficit (`MFVD_leaf`).
- `t_lag`: Time lag between the data logger and the QCL spectrometer in seconds.
- `solar_elevation_angle`: Solar elevation angle calculated from a function based on the NOAA Solar Calculator (<https://www.esrl.noaa.gov/gmd/grad/solcalc/>).
- `MFVD_leaf`: Leaf-to-air vapor deficit in mole fraction (mmol H~2~O mol^–1^ air).
- `daytime_indicator`: Daytime if 1, nighttime if 0.
- `water_table_index`: Standing water exists if 1.


## Leaf relative uptake ratio versus PAR table
File name: `sjm2013_LRU_vs_PAR.csv`

Variable list

- `PAR`: Photosynthetically available radiation flux (µmol m^–2^ s^–1^) received near the leaf chamber (2 m).
- `LRU`: Leaf COS : CO~2~ relative uptake ratio.


## Daily leaf relative uptake values
File name: `sjm2013_daily_LRU.csv`

Variable list

- `date`: Local date (`yyyy-mm-dd`).
- `doy_int`: Day of year number as integer. Note that Jan 1st has the day of year value of 1. 
- `PAR_avg`: Daytime mean photosynthetically available radiation flux near the leaf chamber (µmol m^–2^ s^–1^).
- `n_fcos_dt`, `n_fcos_nt`: Numbers of valid COS flux observations at daytime and nighttime, respectively.
- `n_fco2_dt`, `n_fco2_nt`: Numbers of valid CO~2~ flux observations at daytime and nighttime, respectively.
- `n_cos_dt`, `n_cos_nt`: Numbers of valid COS canopy concentration observations at daytime and nighttime, respectively.
- `n_co2_dt`, `n_co2_nt`: Numbers of valid CO~2~ canopy concentration observations at daytime and nighttime, respectively.
- `flag_calc_LRU`: Mean LRU values are calculated if and only if this variable is `True`.
- `cos_dtavg`, `cos_ntavg`: Daytime and nighttime mean concentrations of COS (pmol mol^–1^), respectively.
- `cos_avg`: 24 h mean concentration of COS (pmol mol^–1^).
- `co2_dtavg`, `co2_ntavg`: Daytime and nighttime mean concentrations of CO~2~ (µmol mol^–1^), respectively.
- `co2_avg`: 24 h mean concentration of CO~2~ (µmol mol^–1^).
- `co2_cos_dtavg`: Daytime mean CO~2~ : COS ratio (µmol pmol^–1^).
- `co2_cos_avg`: 24 h mean CO~2~ : COS ratio (µmol pmol^–1^).
- `fcos_dtavg`, `fcos_ntavg`: Daytime and nighttime mean COS fluxes (pmol m^–2^ s^–1^), respectively.
- `fcos_avg`: 24 h mean COS flux (pmol m^–2^ s^–1^).
- `fco2_dtavg`, `fco2_ntavg`: Daytime and nighttime mean CO~2~ fluxes (µmol m^–2^ s^–1^), respectively.
- `fco2_avg`: 24 h mean CO~2~ flux (µmol m^–2^ s^–1^).
- `LRU_dtavg`: Daytime mean LRU.
- `LRU_avg`: 24 h mean LRU.
- `sem_LRU_dtavg`: Standard error of the daytime mean LRU.
- `sem_LRU_avg`: Standard error of the 24 h mean LRU.


# Contact
For questions regarding this dataset, please contact Wu Sun (wu.sun@ucla.edu) or Ulli Seibt (useibt@ucla.edu).
